@@ -67,14 +67,14 @@ AttackFleet *
 DefenseFleet::spawnAttackFleet( Planet *dest, long long count, int arrivalTurn )
 {
     if( m_shipCount < count ) {
-        return NULL;
+        return nullptr;
     }
 
     AttackFleet *newFleet = new AttackFleet( home, dest, count, arrivalTurn  );
 
     removeShips( count );
 
-    emit update();
+    Q_EMIT update();
     
     return newFleet;
 }
