@@ -21,13 +21,12 @@
  */
 
 #include "game.h"
-#include "players/player.h"
 #include "planet.h"
 #include <KLocalizedString>
 #include <QDebug>
 #include <cmath>
 
-KRandomSequence Game::random = KRandomSequence();
+QRandomGenerator Game::random = QRandomGenerator(QRandomGenerator::global()->generate());
 
 Game::Game(QObject *parent) :
     QObject(parent)
@@ -57,19 +56,19 @@ bool Game::isRunning()
 
 Coordinate Game::generatePlanetCoordinates(int x, int y)
 {
-    return Coordinate(random.getLong(x), random.getLong(y));
+    return Coordinate(random.bounded(x), random.bounded(y));
 }
 
 double Game::generateKillPercentage()
 {
     // 0.30 - 0.90
-    return 0.30 + random.getDouble()*0.60;
+    return 0.30 + random.bounded(0.60);
 }
 
 int Game::generatePlanetProduction()
 {
     // 5 - 15
-    return 5 + random.getLong(10);
+    return 5 + random.bounded(10);
 }
 
 bool Game::attack(Planet *sourcePlanet, Planet *destPlanet, long long shipCount, bool standingOrder)
@@ -113,9 +112,9 @@ bool Game::doFleetArrival(AttackFleet *fleet)
     if( fleet->owner == fleet->destination->player()) {
         fleet->destination->fleet().absorb(fleet);
         if ( !fleet->owner->isAiPlayer() )
-            emit gameMsg(ki18np("Reinforcements (1 ship) have arrived for planet %2.",
+            Q_EMIT gameMsg(ki18np("Reinforcements (1 ship) have arrived for planet %2.",
                             "Reinforcements (%1 ships) have arrived for planet %2.")
-                .subs(fleet->shipCount()), 0, fleet->destination);
+                .subs(fleet->shipCount()), nullptr, fleet->destination);
     } else {
         // let's get ready to rumble...
         AttackFleet   *attacker       = fleet;
@@ -127,8 +126,8 @@ bool Game::doFleetArrival(AttackFleet *fleet)
         bool  planetHolds = true;
 
         while( !haveVictor ) {
-            double  attackerRoll = random.getDouble();
-            double  defenderRoll = random.getDouble();
+            double  attackerRoll = random.bounded(1.0);
+            double  defenderRoll = random.bounded(1.0);
 
             /* special case if both have 0 kill percentages */
             if( defenderPlanet->killPercentage() == 0 &&
@@ -158,7 +157,7 @@ bool Game::doFleetArrival(AttackFleet *fleet)
 
         if( planetHolds ) {
             defenderPlanet->player()->statEnemyFleetsDestroyed(1);
-            emit gameMsg(ki18n("Planet %2 has held against an attack from %1."),
+            Q_EMIT gameMsg(ki18n("Planet %2 has held against an attack from %1."),
                          attacker->owner, defenderPlanet);
         } else {
             Player *defender = defenderPlanet->player();
@@ -166,7 +165,7 @@ bool Game::doFleetArrival(AttackFleet *fleet)
 
             defenderPlanet->conquer( attacker );
 
-            emit gameMsg(ki18n("Planet %2 has fallen to %1."),
+            Q_EMIT gameMsg(ki18n("Planet %2 has fallen to %1."),
                          attacker->owner, defenderPlanet, defender);
         }
     }
@@ -183,7 +182,7 @@ void Game::findWinner()
 {
     //qDebug() << "Searching for survivors";
     // Check for survivors
-    Player *winner = 0;
+    Player *winner = nullptr;
     for (Player *player : players()) {
         if (player->isNeutral() || player->isSpectator()) {
             continue;
@@ -203,6 +202,6 @@ void Game::findWinner()
         // We got a winner
         //qDebug() << "Trying to stop";
         this->stop();
-        emit(finished());
+        Q_EMIT finished();
     }
 }
