@@ -52,7 +52,7 @@ Map::resizeMap (int rowsCount, int columnsCount)
         m_grid << QList<Sector>();
         for (int col = 0; col < columnsCount; col++) {
             m_grid[row] << Sector(this, Coordinate(row, col));
-            connect(&m_grid[row][col], SIGNAL(update()), this, SLOT(childSectorUpdate()));
+            connect(&m_grid[row][col], &Sector::update, this, &Map::childSectorUpdate);
         }
     }
 }
@@ -70,7 +70,7 @@ Map::addPlayerPlanetSomewhere(Player *player)
 {
     Sector *sector = findRandomFreeSector();
     if (!sector)
-        return NULL;
+        return nullptr;
     return Planet::createPlayerPlanet(sector, player, UniquePlanetName());
 }
 
@@ -80,7 +80,7 @@ Map::addNeutralPlanetSomewhere(Player *neutral)
 {
     Sector *sector = findRandomFreeSector();
     if (!sector)
-        return NULL;
+        return nullptr;
     return Planet::createNeutralPlanet(sector, neutral, UniquePlanetName());
 }
 
@@ -88,7 +88,7 @@ Map::addNeutralPlanetSomewhere(Player *neutral)
 bool
 Map::removePlayerPlanet(Player *player)
 {
-    foreach (Planet *planet, planets()) {
+    for (Planet *planet : planets()) {
         if (planet->player() == player) {
             delete planet;
             return true;
@@ -108,7 +108,7 @@ Map::removePlayerPlanets(Player *player)
 void
 Map::turnOverPlayerPlanets(Player* owner, Player* newOwner)
 {
-    foreach (Planet *planet, planets()) {
+    for (Planet *planet : planets()) {
         if (planet->player() == owner) {
             planet->setOwner(newOwner);
         }
@@ -120,7 +120,7 @@ int
 Map::playerPlanetCount(Player *player)
 {
     int count = 0;
-    foreach (Planet *planet, planets()) {
+    for (Planet *planet : planets()) {
         if (planet->player() == player) {
             count++;
         }
@@ -138,7 +138,7 @@ Map::clearMap()
         }
     }
 
-    emit update();
+    Q_EMIT update();
 }
 
 
@@ -147,13 +147,13 @@ Map::UniquePlanetName(void)
 {
     char c = 'A';
 again:
-    foreach(Planet *planet, planets()) {
-        if (planet->name().at(0).toAscii() == c) {
+    for (Planet *planet : planets()) {
+        if (planet->name().at(0).toLatin1() == c) {
             c++;
             goto again;
         }
     }
-    return QChar(c);
+    return QChar::fromLatin1(c);
 }
 
 
@@ -161,7 +161,7 @@ void
 Map::populateMap(const QList<Player *> &players, Player *neutral, int numNeutralPlanets)
 {
     // Create a planet for each player.
-    foreach (Player *player, players) {
+    for (Player *player : players) {
         addPlayerPlanetSomewhere(player);
     }
 
@@ -172,7 +172,7 @@ Map::populateMap(const QList<Player *> &players, Player *neutral, int numNeutral
         }
     }
 
-    emit update();
+    Q_EMIT update();
 }
 
 
@@ -188,15 +188,15 @@ Map::distance(Planet *p1, Planet *p2)
 Sector*
 Map::findRandomFreeSector()
 {
-    foreach (const QList<Sector> &i, m_grid) {
-        foreach (const Sector &j, i) {
+    for (const QList<Sector> &i : qAsConst(m_grid)) {
+        for (const Sector &j : i) {
             if (!j.hasPlanet()) {
                 goto freesectorexists;
             }
         }
     }
 
-    return NULL;
+    return nullptr;
 
 freesectorexists:
 
@@ -213,16 +213,16 @@ freesectorexists:
 void
 Map::childSectorUpdate()
 {
-    emit update();
+    Q_EMIT update();
 }
 
 
-QList <Planet*>
+const QList <Planet*>
 Map::planets()
 {
     QList <Planet*>planets;
-    foreach (const QList<Sector> &i, m_grid) {
-        foreach (const Sector &j, i) {
+    for (const QList<Sector> &i : qAsConst(m_grid)) {
+        for (const Sector &j : i) {
             if (j.hasPlanet()) {
                 planets += j.planet();
             }
