@@ -23,14 +23,9 @@
 
 class AiDefaultHard : public AiDefault
 {
-    Q_OBJECT
 public:
     explicit AiDefaultHard(Game *game, const QString &newName, const QColor &color);
 
-signals:
-
-public slots:
-
 };
 
 #endif // AI_DEFAULT_HARD_H
