@@ -31,13 +31,12 @@ class LocalPlayer : public Player
 public:
     explicit LocalPlayer(Game *game, const QString &newName, const QColor &color);
 
-    virtual void play();
+    void play() override;
 
     void done();
-signals:
-    void canPlay();
 
-public slots:
+Q_SIGNALS:
+    void canPlay();
 
 };
 
